jenkins-bot has submitted this change and it was merged. (
https://gerrit.wikimedia.org/r/403143 )
Change subject: Use IDatabase interface instead of Database in DBAccessBase
......................................................................
Use IDatabase interface instead of Database in DBAccessBase
There is one subclass I'm aware of that overwrites the releaseConnection
method. It's in the EducationProgram extension and already updated, see
Ibb067ca.
Change-Id: I68504f9cd32aa0d0c6c068dbaa1f2ee65649afa4
---
M includes/dao/DBAccessBase.php
1 file changed, 4 insertions(+), 4 deletions(-)
Approvals:
Daniel Kinzler: Looks good to me, approved
jenkins-bot: Verified
diff --git a/includes/dao/DBAccessBase.php b/includes/dao/DBAccessBase.php
index 0f8d7f7..6e171d5 100644
--- a/includes/dao/DBAccessBase.php
+++ b/includes/dao/DBAccessBase.php
@@ -1,6 +1,6 @@
<?php
-use Wikimedia\Rdbms\Database;
+use Wikimedia\Rdbms\IDatabase;
use Wikimedia\Rdbms\LoadBalancer;
/**
@@ -56,7 +56,7 @@
* @param int $id Which connection to use
* @param array $groups Query groups
*
- * @return Database
+ * @return IDatabase
*/
protected function getConnection( $id, $groups = [] ) {
$loadBalancer = wfGetLB( $this->wiki );
@@ -71,9 +71,9 @@
*
* @since 1.21
*
* @param Database $db The database connection to release.
*/
- protected function releaseConnection( Database $db ) {
+ protected function releaseConnection( IDatabase $db ) {
if ( $this->wiki !== false ) {
$loadBalancer = $this->getLoadBalancer();
$loadBalancer->reuseConnection( $db );
@@ -71,9 +71,9 @@
* @since 1.21
*
- * @param Database $db The database connection to release.
+ * @param IDatabase $db The database connection to release.
*/
--
To view, visit https://gerrit.wikimedia.org/r/403143
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings
Gerrit-MessageType: merged
Gerrit-Change-Id: I68504f9cd32aa0d0c6c068dbaa1f2ee65649afa4
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Thiemo Kreuz (WMDE) <[email protected]>
Gerrit-Reviewer: Daniel Kinzler <[email protected]>
Gerrit-Reviewer: Umherirrender <[email protected]>
Gerrit-Reviewer: jenkins-bot <>
_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits